@@ -4,6 +4,8 @@ from select_alias_checker import SelectAliasChecker
 from select_cast_checker import SelectCastChecker
 from statement_call_checker import StatementCallChecker
 from chained_function_checker import ChainedDotFunctionsSyntaxChecker
+from confluence_page_checker import ConfluencePageChecker
+
 
 def register(linter):
     linter.register_checker(FunctionCallChecker(linter))
@@ -12,3 +14,4 @@ def register(linter):
     linter.register_checker(SelectCastChecker(linter))
     linter.register_checker(StatementCallChecker(linter))
     linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
+    linter.register_checker(ConfluencePageChecker(linter))
